# == Class consul_template::params
#
# This class is meant to be called from consul_template.
# It sets variables according to platform.
#
class consul_template::params {

  $os = downcase($::kernel)

  case $::architecture {
    'x86_64', 'amd64': {
      $arch = 'amd64'
    }

    'i386': {
      $arch = '386'
    }

    default: {
      fail("Unsupported kernel architecture: ${::architecture}")
    }
  }

  $init_style = $::operatingsystem ? {
    'Ubuntu' => $::lsbdistrelease ? {
      '8.04'  => 'debian',
      '15.04' => 'systemd',
      '16.04' => 'systemd',
      default => 'upstart'
    },

    /CentOS|RedHat/ => $::operatingsystemmajrelease ? {
      /(4|5|6)/ => 'sysv',
      default   => 'systemd',
    },

    'Fedora'        => $::operatingsystemmajrelease ? {
      /(12|13|14)/ => 'sysv',
      default      => 'systemd',
    },

    'Debian'        =>  $::operatingsystemmajrelease ? {
      /(4|5|6|7)/ => 'debian',
      default     => 'systemd'
    },

    default => 'sysv'
  }
}
